package com.fizz.business.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fizz.business.mapper.SetupFurTempMapper;
import com.fizz.business.domain.SetupFurTemp;
import com.fizz.business.service.ISetupFurTempService;

/**
 * 炉火段工艺参数Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-09-29
 */
@Service
public class SetupFurTempServiceImpl implements ISetupFurTempService 
{
    @Autowired
    private SetupFurTempMapper setupFurTempMapper;

    /**
     * 查询炉火段工艺参数
     * 
     * @param steelGrade 炉火段工艺参数主键
     * @return 炉火段工艺参数
     */
    @Override
    public SetupFurTemp selectSetupFurTempBySteelGrade(String steelGrade)
    {
        return setupFurTempMapper.selectSetupFurTempBySteelGrade(steelGrade);
    }

    /**
     * 查询炉火段工艺参数列表
     * 
     * @param setupFurTemp 炉火段工艺参数
     * @return 炉火段工艺参数
     */
    @Override
    public List<SetupFurTemp> selectSetupFurTempList(SetupFurTemp setupFurTemp)
    {
        return setupFurTempMapper.selectSetupFurTempList(setupFurTemp);
    }

    /**
     * 新增炉火段工艺参数
     * 
     * @param setupFurTemp 炉火段工艺参数
     * @return 结果
     */
    @Override
    public int insertSetupFurTemp(SetupFurTemp setupFurTemp)
    {
        setupFurTemp.setCreateTime(DateUtils.getNowDate());
        return setupFurTempMapper.insertSetupFurTemp(setupFurTemp);
    }

    /**
     * 修改炉火段工艺参数
     * 
     * @param setupFurTemp 炉火段工艺参数
     * @return 结果
     */
    @Override
    public int updateSetupFurTemp(SetupFurTemp setupFurTemp)
    {
        setupFurTemp.setUpdateTime(DateUtils.getNowDate());
        return setupFurTempMapper.updateSetupFurTemp(setupFurTemp);
    }

    /**
     * 批量删除炉火段工艺参数
     * 
     * @param steelGrades 需要删除的炉火段工艺参数主键
     * @return 结果
     */
    @Override
    public int deleteSetupFurTempBySteelGrades(String[] steelGrades)
    {
        return setupFurTempMapper.deleteSetupFurTempBySteelGrades(steelGrades);
    }

    /**
     * 删除炉火段工艺参数信息
     * 
     * @param steelGrade 炉火段工艺参数主键
     * @return 结果
     */
    @Override
    public int deleteSetupFurTempBySteelGrade(String steelGrade)
    {
        return setupFurTempMapper.deleteSetupFurTempBySteelGrade(steelGrade);
    }
}
